/*
    This file is part of the WebKit open source project.
    This file has been generated by generate-bindings.pl. DO NOT MODIFY!

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMValidityState_h
#define WebKitDOMValidityState_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMObject.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_TYPE_DOM_VALIDITY_STATE            (webkit_dom_validity_state_get_type())
#define WEBKIT_DOM_VALIDITY_STATE(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_DOM_VALIDITY_STATE, WebKitDOMValidityState))
#define WEBKIT_DOM_VALIDITY_STATE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_DOM_VALIDITY_STATE, WebKitDOMValidityStateClass)
#define WEBKIT_DOM_IS_VALIDITY_STATE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_DOM_VALIDITY_STATE))
#define WEBKIT_DOM_IS_VALIDITY_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_DOM_VALIDITY_STATE))
#define WEBKIT_DOM_VALIDITY_STATE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_DOM_VALIDITY_STATE, WebKitDOMValidityStateClass))

struct _WebKitDOMValidityState {
    WebKitDOMObject parent_instance;
};

struct _WebKitDOMValidityStateClass {
    WebKitDOMObjectClass parent_class;
};

WEBKIT_API GType
webkit_dom_validity_state_get_type (void);

/**
 * webkit_dom_validity_state_get_value_missing:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_value_missing(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_type_mismatch:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_type_mismatch(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_pattern_mismatch:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_pattern_mismatch(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_too_long:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_too_long(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_range_underflow:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_range_underflow(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_range_overflow:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_range_overflow(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_step_mismatch:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_step_mismatch(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_bad_input:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_bad_input(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_custom_error:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_custom_error(WebKitDOMValidityState* self);

/**
 * webkit_dom_validity_state_get_valid:
 * @self: A #WebKitDOMValidityState
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_validity_state_get_valid(WebKitDOMValidityState* self);

G_END_DECLS

#endif /* WebKitDOMValidityState_h */
