/*
    This file is part of the WebKit open source project.
    This file has been generated by generate-bindings.pl. DO NOT MODIFY!

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMTextTrackCue_h
#define WebKitDOMTextTrackCue_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMObject.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_TYPE_DOM_TEXT_TRACK_CUE            (webkit_dom_text_track_cue_get_type())
#define WEBKIT_DOM_TEXT_TRACK_CUE(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_DOM_TEXT_TRACK_CUE, WebKitDOMTextTrackCue))
#define WEBKIT_DOM_TEXT_TRACK_CUE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_DOM_TEXT_TRACK_CUE, WebKitDOMTextTrackCueClass)
#define WEBKIT_DOM_IS_TEXT_TRACK_CUE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_DOM_TEXT_TRACK_CUE))
#define WEBKIT_DOM_IS_TEXT_TRACK_CUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_DOM_TEXT_TRACK_CUE))
#define WEBKIT_DOM_TEXT_TRACK_CUE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_DOM_TEXT_TRACK_CUE, WebKitDOMTextTrackCueClass))

struct _WebKitDOMTextTrackCue {
    WebKitDOMObject parent_instance;
};

struct _WebKitDOMTextTrackCueClass {
    WebKitDOMObjectClass parent_class;
};

WEBKIT_API GType
webkit_dom_text_track_cue_get_type (void);

/**
 * webkit_dom_text_track_cue_get_cue_as_html:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMDocumentFragment*
webkit_dom_text_track_cue_get_cue_as_html(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_dispatch_event:
 * @self: A #WebKitDOMTextTrackCue
 * @evt: A #WebKitDOMEvent
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_text_track_cue_dispatch_event(WebKitDOMTextTrackCue* self, WebKitDOMEvent* evt, GError** error);

/**
 * webkit_dom_text_track_cue_get_track:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMTextTrack*
webkit_dom_text_track_cue_get_track(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_get_id:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_text_track_cue_get_id(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_id:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_id(WebKitDOMTextTrackCue* self, const gchar* value);

/**
 * webkit_dom_text_track_cue_get_start_time:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gdouble
webkit_dom_text_track_cue_get_start_time(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_start_time:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gdouble
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_start_time(WebKitDOMTextTrackCue* self, gdouble value, GError** error);

/**
 * webkit_dom_text_track_cue_get_end_time:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gdouble
webkit_dom_text_track_cue_get_end_time(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_end_time:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gdouble
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_end_time(WebKitDOMTextTrackCue* self, gdouble value, GError** error);

/**
 * webkit_dom_text_track_cue_get_pause_on_exit:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_text_track_cue_get_pause_on_exit(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_pause_on_exit:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gboolean
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_pause_on_exit(WebKitDOMTextTrackCue* self, gboolean value);

/**
 * webkit_dom_text_track_cue_get_vertical:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_text_track_cue_get_vertical(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_vertical:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gchar
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_vertical(WebKitDOMTextTrackCue* self, const gchar* value, GError** error);

/**
 * webkit_dom_text_track_cue_get_snap_to_lines:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_text_track_cue_get_snap_to_lines(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_snap_to_lines:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gboolean
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_snap_to_lines(WebKitDOMTextTrackCue* self, gboolean value);

/**
 * webkit_dom_text_track_cue_get_line:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_text_track_cue_get_line(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_line:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #glong
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_line(WebKitDOMTextTrackCue* self, glong value, GError** error);

/**
 * webkit_dom_text_track_cue_get_position:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_text_track_cue_get_position(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_position:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #glong
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_position(WebKitDOMTextTrackCue* self, glong value, GError** error);

/**
 * webkit_dom_text_track_cue_get_size:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_text_track_cue_get_size(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_size:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #glong
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_size(WebKitDOMTextTrackCue* self, glong value, GError** error);

/**
 * webkit_dom_text_track_cue_get_align:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_text_track_cue_get_align(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_align:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gchar
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_align(WebKitDOMTextTrackCue* self, const gchar* value, GError** error);

/**
 * webkit_dom_text_track_cue_get_text:
 * @self: A #WebKitDOMTextTrackCue
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_text_track_cue_get_text(WebKitDOMTextTrackCue* self);

/**
 * webkit_dom_text_track_cue_set_text:
 * @self: A #WebKitDOMTextTrackCue
 * @value: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_text_track_cue_set_text(WebKitDOMTextTrackCue* self, const gchar* value);

G_END_DECLS

#endif /* WebKitDOMTextTrackCue_h */
