/*
    This file is part of the WebKit open source project.
    This file has been generated by generate-bindings.pl. DO NOT MODIFY!

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMHTMLPropertiesCollection_h
#define WebKitDOMHTMLPropertiesCollection_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMHTMLCollection.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_TYPE_DOM_HTML_PROPERTIES_COLLECTION            (webkit_dom_html_properties_collection_get_type())
#define WEBKIT_DOM_HTML_PROPERTIES_COLLECTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_DOM_HTML_PROPERTIES_COLLECTION, WebKitDOMHTMLPropertiesCollection))
#define WEBKIT_DOM_HTML_PROPERTIES_COLLECTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_DOM_HTML_PROPERTIES_COLLECTION, WebKitDOMHTMLPropertiesCollectionClass)
#define WEBKIT_DOM_IS_HTML_PROPERTIES_COLLECTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_DOM_HTML_PROPERTIES_COLLECTION))
#define WEBKIT_DOM_IS_HTML_PROPERTIES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_DOM_HTML_PROPERTIES_COLLECTION))
#define WEBKIT_DOM_HTML_PROPERTIES_COLLECTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_DOM_HTML_PROPERTIES_COLLECTION, WebKitDOMHTMLPropertiesCollectionClass))

struct _WebKitDOMHTMLPropertiesCollection {
    WebKitDOMHTMLCollection parent_instance;
};

struct _WebKitDOMHTMLPropertiesCollectionClass {
    WebKitDOMHTMLCollectionClass parent_class;
};

WEBKIT_API GType
webkit_dom_html_properties_collection_get_type (void);

/**
 * webkit_dom_html_properties_collection_item:
 * @self: A #WebKitDOMHTMLPropertiesCollection
 * @index: A #gulong
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNode*
webkit_dom_html_properties_collection_item(WebKitDOMHTMLPropertiesCollection* self, gulong index);

/**
 * webkit_dom_html_properties_collection_named_item:
 * @self: A #WebKitDOMHTMLPropertiesCollection
 * @name: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMPropertyNodeList*
webkit_dom_html_properties_collection_named_item(WebKitDOMHTMLPropertiesCollection* self, const gchar* name);

/**
 * webkit_dom_html_properties_collection_get_length:
 * @self: A #WebKitDOMHTMLPropertiesCollection
 *
 * Returns:
 *
**/
WEBKIT_API gulong
webkit_dom_html_properties_collection_get_length(WebKitDOMHTMLPropertiesCollection* self);

/**
 * webkit_dom_html_properties_collection_get_names:
 * @self: A #WebKitDOMHTMLPropertiesCollection
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMDOMStringList*
webkit_dom_html_properties_collection_get_names(WebKitDOMHTMLPropertiesCollection* self);

G_END_DECLS

#endif /* WebKitDOMHTMLPropertiesCollection_h */
