/*
    This file is part of the WebKit open source project.
    This file has been generated by generate-bindings.pl. DO NOT MODIFY!

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMShadowRoot_h
#define WebKitDOMShadowRoot_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMDocumentFragment.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_TYPE_DOM_SHADOW_ROOT            (webkit_dom_shadow_root_get_type())
#define WEBKIT_DOM_SHADOW_ROOT(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_DOM_SHADOW_ROOT, WebKitDOMShadowRoot))
#define WEBKIT_DOM_SHADOW_ROOT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_DOM_SHADOW_ROOT, WebKitDOMShadowRootClass)
#define WEBKIT_DOM_IS_SHADOW_ROOT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_DOM_SHADOW_ROOT))
#define WEBKIT_DOM_IS_SHADOW_ROOT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_DOM_SHADOW_ROOT))
#define WEBKIT_DOM_SHADOW_ROOT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_DOM_SHADOW_ROOT, WebKitDOMShadowRootClass))

struct _WebKitDOMShadowRoot {
    WebKitDOMDocumentFragment parent_instance;
};

struct _WebKitDOMShadowRootClass {
    WebKitDOMDocumentFragmentClass parent_class;
};

WEBKIT_API GType
webkit_dom_shadow_root_get_type (void);

/**
 * webkit_dom_shadow_root_get_selection:
 * @self: A #WebKitDOMShadowRoot
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMDOMSelection*
webkit_dom_shadow_root_get_selection(WebKitDOMShadowRoot* self);

/**
 * webkit_dom_shadow_root_get_element_by_id:
 * @self: A #WebKitDOMShadowRoot
 * @elementId: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_shadow_root_get_element_by_id(WebKitDOMShadowRoot* self, const gchar* elementId);

/**
 * webkit_dom_shadow_root_get_elements_by_class_name:
 * @self: A #WebKitDOMShadowRoot
 * @className: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_shadow_root_get_elements_by_class_name(WebKitDOMShadowRoot* self, const gchar* className);

/**
 * webkit_dom_shadow_root_get_elements_by_tag_name:
 * @self: A #WebKitDOMShadowRoot
 * @tagName: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_shadow_root_get_elements_by_tag_name(WebKitDOMShadowRoot* self, const gchar* tagName);

/**
 * webkit_dom_shadow_root_get_elements_by_tag_name_ns:
 * @self: A #WebKitDOMShadowRoot
 * @namespaceURI: A #gchar
 * @localName: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_shadow_root_get_elements_by_tag_name_ns(WebKitDOMShadowRoot* self, const gchar* namespaceURI, const gchar* localName);

/**
 * webkit_dom_shadow_root_element_from_point:
 * @self: A #WebKitDOMShadowRoot
 * @x: A #glong
 * @y: A #glong
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_shadow_root_element_from_point(WebKitDOMShadowRoot* self, glong x, glong y);

/**
 * webkit_dom_shadow_root_get_active_element:
 * @self: A #WebKitDOMShadowRoot
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_shadow_root_get_active_element(WebKitDOMShadowRoot* self);

/**
 * webkit_dom_shadow_root_get_apply_author_styles:
 * @self: A #WebKitDOMShadowRoot
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_shadow_root_get_apply_author_styles(WebKitDOMShadowRoot* self);

/**
 * webkit_dom_shadow_root_set_apply_author_styles:
 * @self: A #WebKitDOMShadowRoot
 * @value: A #gboolean
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_shadow_root_set_apply_author_styles(WebKitDOMShadowRoot* self, gboolean value);

/**
 * webkit_dom_shadow_root_get_reset_style_inheritance:
 * @self: A #WebKitDOMShadowRoot
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_shadow_root_get_reset_style_inheritance(WebKitDOMShadowRoot* self);

/**
 * webkit_dom_shadow_root_set_reset_style_inheritance:
 * @self: A #WebKitDOMShadowRoot
 * @value: A #gboolean
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_shadow_root_set_reset_style_inheritance(WebKitDOMShadowRoot* self, gboolean value);

/**
 * webkit_dom_shadow_root_get_inner_html:
 * @self: A #WebKitDOMShadowRoot
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_shadow_root_get_inner_html(WebKitDOMShadowRoot* self);

/**
 * webkit_dom_shadow_root_set_inner_html:
 * @self: A #WebKitDOMShadowRoot
 * @value: A #gchar
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_shadow_root_set_inner_html(WebKitDOMShadowRoot* self, const gchar* value, GError** error);

G_END_DECLS

#endif /* WebKitDOMShadowRoot_h */
