/*
    This file is part of the WebKit open source project.
    This file has been generated by generate-bindings.pl. DO NOT MODIFY!

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMElement_h
#define WebKitDOMElement_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMNode.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_TYPE_DOM_ELEMENT            (webkit_dom_element_get_type())
#define WEBKIT_DOM_ELEMENT(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_DOM_ELEMENT, WebKitDOMElement))
#define WEBKIT_DOM_ELEMENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_DOM_ELEMENT, WebKitDOMElementClass)
#define WEBKIT_DOM_IS_ELEMENT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_DOM_ELEMENT))
#define WEBKIT_DOM_IS_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_DOM_ELEMENT))
#define WEBKIT_DOM_ELEMENT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_DOM_ELEMENT, WebKitDOMElementClass))

struct _WebKitDOMElement {
    WebKitDOMNode parent_instance;
};

struct _WebKitDOMElementClass {
    WebKitDOMNodeClass parent_class;
};

WEBKIT_API GType
webkit_dom_element_get_type (void);

/**
 * webkit_dom_element_get_attribute:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_element_get_attribute(WebKitDOMElement* self, const gchar* name);

/**
 * webkit_dom_element_set_attribute:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 * @value: A #gchar
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_set_attribute(WebKitDOMElement* self, const gchar* name, const gchar* value, GError** error);

/**
 * webkit_dom_element_remove_attribute:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_remove_attribute(WebKitDOMElement* self, const gchar* name);

/**
 * webkit_dom_element_get_attribute_node:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMAttr*
webkit_dom_element_get_attribute_node(WebKitDOMElement* self, const gchar* name);

/**
 * webkit_dom_element_set_attribute_node:
 * @self: A #WebKitDOMElement
 * @newAttr: A #WebKitDOMAttr
 * @error: #GError
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMAttr*
webkit_dom_element_set_attribute_node(WebKitDOMElement* self, WebKitDOMAttr* newAttr, GError** error);

/**
 * webkit_dom_element_remove_attribute_node:
 * @self: A #WebKitDOMElement
 * @oldAttr: A #WebKitDOMAttr
 * @error: #GError
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMAttr*
webkit_dom_element_remove_attribute_node(WebKitDOMElement* self, WebKitDOMAttr* oldAttr, GError** error);

/**
 * webkit_dom_element_get_elements_by_tag_name:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_element_get_elements_by_tag_name(WebKitDOMElement* self, const gchar* name);

/**
 * webkit_dom_element_has_attributes:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_element_has_attributes(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_attribute_ns:
 * @self: A #WebKitDOMElement
 * @namespaceURI: A #gchar
 * @localName: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_element_get_attribute_ns(WebKitDOMElement* self, const gchar* namespaceURI, const gchar* localName);

/**
 * webkit_dom_element_set_attribute_ns:
 * @self: A #WebKitDOMElement
 * @namespaceURI: A #gchar
 * @qualifiedName: A #gchar
 * @value: A #gchar
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_set_attribute_ns(WebKitDOMElement* self, const gchar* namespaceURI, const gchar* qualifiedName, const gchar* value, GError** error);

/**
 * webkit_dom_element_remove_attribute_ns:
 * @self: A #WebKitDOMElement
 * @namespaceURI: A #gchar
 * @localName: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_remove_attribute_ns(WebKitDOMElement* self, const gchar* namespaceURI, const gchar* localName);

/**
 * webkit_dom_element_get_elements_by_tag_name_ns:
 * @self: A #WebKitDOMElement
 * @namespaceURI: A #gchar
 * @localName: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_element_get_elements_by_tag_name_ns(WebKitDOMElement* self, const gchar* namespaceURI, const gchar* localName);

/**
 * webkit_dom_element_get_attribute_node_ns:
 * @self: A #WebKitDOMElement
 * @namespaceURI: A #gchar
 * @localName: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMAttr*
webkit_dom_element_get_attribute_node_ns(WebKitDOMElement* self, const gchar* namespaceURI, const gchar* localName);

/**
 * webkit_dom_element_set_attribute_node_ns:
 * @self: A #WebKitDOMElement
 * @newAttr: A #WebKitDOMAttr
 * @error: #GError
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMAttr*
webkit_dom_element_set_attribute_node_ns(WebKitDOMElement* self, WebKitDOMAttr* newAttr, GError** error);

/**
 * webkit_dom_element_has_attribute:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_element_has_attribute(WebKitDOMElement* self, const gchar* name);

/**
 * webkit_dom_element_has_attribute_ns:
 * @self: A #WebKitDOMElement
 * @namespaceURI: A #gchar
 * @localName: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_element_has_attribute_ns(WebKitDOMElement* self, const gchar* namespaceURI, const gchar* localName);

/**
 * webkit_dom_element_focus:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_focus(WebKitDOMElement* self);

/**
 * webkit_dom_element_blur:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_blur(WebKitDOMElement* self);

/**
 * webkit_dom_element_scroll_into_view:
 * @self: A #WebKitDOMElement
 * @alignWithTop: A #gboolean
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_scroll_into_view(WebKitDOMElement* self, gboolean alignWithTop);

/**
 * webkit_dom_element_scroll_into_view_if_needed:
 * @self: A #WebKitDOMElement
 * @centerIfNeeded: A #gboolean
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_scroll_into_view_if_needed(WebKitDOMElement* self, gboolean centerIfNeeded);

/**
 * webkit_dom_element_scroll_by_lines:
 * @self: A #WebKitDOMElement
 * @lines: A #glong
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_scroll_by_lines(WebKitDOMElement* self, glong lines);

/**
 * webkit_dom_element_scroll_by_pages:
 * @self: A #WebKitDOMElement
 * @pages: A #glong
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_scroll_by_pages(WebKitDOMElement* self, glong pages);

/**
 * webkit_dom_element_get_elements_by_class_name:
 * @self: A #WebKitDOMElement
 * @name: A #gchar
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_element_get_elements_by_class_name(WebKitDOMElement* self, const gchar* name);

/**
 * webkit_dom_element_query_selector:
 * @self: A #WebKitDOMElement
 * @selectors: A #gchar
 * @error: #GError
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_element_query_selector(WebKitDOMElement* self, const gchar* selectors, GError** error);

/**
 * webkit_dom_element_query_selector_all:
 * @self: A #WebKitDOMElement
 * @selectors: A #gchar
 * @error: #GError
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNodeList*
webkit_dom_element_query_selector_all(WebKitDOMElement* self, const gchar* selectors, GError** error);

/**
 * webkit_dom_element_webkit_matches_selector:
 * @self: A #WebKitDOMElement
 * @selectors: A #gchar
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API gboolean
webkit_dom_element_webkit_matches_selector(WebKitDOMElement* self, const gchar* selectors, GError** error);

/**
 * webkit_dom_element_remove:
 * @self: A #WebKitDOMElement
 * @error: #GError
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_remove(WebKitDOMElement* self, GError** error);

/**
 * webkit_dom_element_webkit_request_full_screen:
 * @self: A #WebKitDOMElement
 * @flags: A #gushort
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_webkit_request_full_screen(WebKitDOMElement* self, gushort flags);

/**
 * webkit_dom_element_webkit_request_fullscreen:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_webkit_request_fullscreen(WebKitDOMElement* self);

/**
 * webkit_dom_element_webkit_request_pointer_lock:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_webkit_request_pointer_lock(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_tag_name:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_element_get_tag_name(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_attributes:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMNamedNodeMap*
webkit_dom_element_get_attributes(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_style:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMCSSStyleDeclaration*
webkit_dom_element_get_style(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_id:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_element_get_id(WebKitDOMElement* self);

/**
 * webkit_dom_element_set_id:
 * @self: A #WebKitDOMElement
 * @value: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_set_id(WebKitDOMElement* self, const gchar* value);

/**
 * webkit_dom_element_get_offset_left:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_offset_left(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_offset_top:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_offset_top(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_offset_width:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_offset_width(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_offset_height:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_offset_height(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_offset_parent:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_element_get_offset_parent(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_client_left:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_client_left(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_client_top:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_client_top(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_client_width:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_client_width(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_client_height:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_client_height(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_scroll_left:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_scroll_left(WebKitDOMElement* self);

/**
 * webkit_dom_element_set_scroll_left:
 * @self: A #WebKitDOMElement
 * @value: A #glong
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_set_scroll_left(WebKitDOMElement* self, glong value);

/**
 * webkit_dom_element_get_scroll_top:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_scroll_top(WebKitDOMElement* self);

/**
 * webkit_dom_element_set_scroll_top:
 * @self: A #WebKitDOMElement
 * @value: A #glong
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_set_scroll_top(WebKitDOMElement* self, glong value);

/**
 * webkit_dom_element_get_scroll_width:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_scroll_width(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_scroll_height:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API glong
webkit_dom_element_get_scroll_height(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_class_name:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_element_get_class_name(WebKitDOMElement* self);

/**
 * webkit_dom_element_set_class_name:
 * @self: A #WebKitDOMElement
 * @value: A #gchar
 *
 * Returns:
 *
**/
WEBKIT_API void
webkit_dom_element_set_class_name(WebKitDOMElement* self, const gchar* value);

/**
 * webkit_dom_element_get_class_list:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMDOMTokenList*
webkit_dom_element_get_class_list(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_first_element_child:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_element_get_first_element_child(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_last_element_child:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_element_get_last_element_child(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_previous_element_sibling:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_element_get_previous_element_sibling(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_next_element_sibling:
 * @self: A #WebKitDOMElement
 *
 * Returns: (transfer none):
 *
**/
WEBKIT_API WebKitDOMElement*
webkit_dom_element_get_next_element_sibling(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_child_element_count:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API gulong
webkit_dom_element_get_child_element_count(WebKitDOMElement* self);

/**
 * webkit_dom_element_get_webkit_region_overset:
 * @self: A #WebKitDOMElement
 *
 * Returns:
 *
**/
WEBKIT_API gchar*
webkit_dom_element_get_webkit_region_overset(WebKitDOMElement* self);

G_END_DECLS

#endif /* WebKitDOMElement_h */
